<?php
/**
 * ReduxFramework Sample File
 * For full documentation, please visit: http://docs.reduxframework.com/
 */

if ( ! class_exists( 'Redux' ) ) {
  return;
}

// This is your option name where all the Redux data is stored.
$opt_name = "redux_opt";
// This line is only for altering the demo. Can be easily removed.
$opt_name = apply_filters( 'redux_opt/opt_name', $opt_name );

$sampleHTML = '';
if ( file_exists( get_template_directory() . '/info-html.html' ) ) {
  Redux_Functions::initWpFilesystem();
  global $wp_filesystem;
  $sampleHTML = $wp_filesystem->get_contents( get_template_directory() . '/info-html.html' );
}

$theme = wp_get_theme(); // For use with some settings. Not necessary.
$themeworm_api_key = get_option('themeworm_api_key') ?: '';
$args = array(
  // TYPICAL -> Change these values as you need/desire
  'opt_name'             => $opt_name,
  'show_options_object' => false,
  // This is where your data is stored in the database and also becomes your global variable name.
  'display_name'         => $theme->get( 'Name' ),
  // Name that appears at the top of your panel
  'display_version'      => $theme->get( 'Version' ),
  // Version that appears at the top of your panel
  'menu_type'            => 'menu',
  //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
  'allow_sub_menu'       => true,
  // Show the sections below the admin menu item or not
  'menu_title'           => __( 'Theme Options', 'coffeebean' ),
  'page_title'           => __( 'Theme Options', 'coffeebean' ),
  // You will need to generate a Google API key to use this feature.
  // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
  'google_api_key'       => $themeworm_api_key,
  // Set it you want google fonts to update weekly. A google_api_key value is required.
  'google_update_weekly' => false,
  // Must be defined to add google fonts to the typography module
  'async_typography'     => true,
  // Use a asynchronous font on the front end or font string
  //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
  'admin_bar'            => true,
  // Show the panel pages on the admin bar
  'admin_bar_icon'       => 'dashicons-portfolio',
  // Choose an icon for the admin bar menu
  'admin_bar_priority'   => 50,
  // Choose an priority for the admin bar menu
  'global_variable'      => '',
  // Set a different name for your global variable other than the opt_name
  'dev_mode'             => false,
  // Show the time the page took to load, etc
  'update_notice'        => false,
  // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
  'customizer'           => false,
  // Enable basic customizer support
  //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
  'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

  // OPTIONAL -> Give you extra features
  'page_priority'        => null,
  // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
  'page_parent'          => 'themes.php',
  // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
  'page_permissions'     => 'manage_options',
  // Permissions needed to access the options panel.
  'menu_icon'            => '',
  // Specify a custom URL to an icon
  'last_tab'             => '',
  // Force your panel to always open to a specific tab (by id)
  'page_icon'            => 'icon-themes',
  // Icon displayed in the admin panel next to your menu_title
  'page_slug'            => '',
  // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
  'save_defaults'        => true,
  // On load save the defaults to DB before user clicks save or not
  'default_show'         => false,
  // If true, shows the default value next to each field that is not the default value.
  'default_mark'         => '',
  // What to print by the field's title if the value shown is default. Suggested: *
  'show_import_export'   => false,
  // Shows the Import/Export panel when not used as a field.

  // CAREFUL -> These options are for advanced use only
  'transient_time'       => 60 * MINUTE_IN_SECONDS,
  'output'               => true,
  // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
  'output_tag'           => true,
  // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
  'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

  // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
  'database'             => '',
  // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
  'use_cdn'              => true,
  // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

  // HINTS
  'hints'                => array(
    'icon'          => 'el el-question-sign',
    'icon_position' => 'right',
    'icon_color'    => 'lightgray',
    'icon_size'     => 'normal',
    'tip_style'     => array(
      'color'   => 'red',
      'shadow'  => true,
      'rounded' => false,
      'style'   => '',
    ),
    'tip_position'  => array(
      'my' => 'top left',
      'at' => 'bottom right',
    ),
    'tip_effect'    => array(
      'show' => array(
        'effect'   => 'slide',
        'duration' => '500',
        'event'    => 'mouseover',
      ),
      'hide' => array(
        'effect'   => 'slide',
        'duration' => '500',
        'event'    => 'click mouseleave',
      ),
    ),
  )
);

Redux::setArgs( $opt_name, $args );

Redux::setSection( $opt_name, array(
  'title'            => esc_html__( 'General settings', 'coffeebean' ),
  'id'               => 'general',
  'customizer_width' => '400px',
  'desc'             => esc_html__( 'General setting', 'coffeebean' ),
  'fields'           => array(
    array(
      'id'       => 'preloader_on',
      'type'     => 'switch',
      'title'    => esc_html__( 'Page preloader', 'coffeebean' ),
      'subtitle' => esc_html__( 'Turn off Page preloader.', 'coffeebean' ),
      'default'  => true
    ),
    array(
      'id'       => 'projectnav_on',
      'type'     => 'switch',
      'title'    => esc_html__( 'Navigation arrows in Projects and Posts', 'coffeebean' ),
      'subtitle' => esc_html__( 'Turn off Navigation arrows.', 'coffeebean' ),
      'default'  => true
    ),
    array(
      'id'       => 'custom_css',
      'type'     => 'ace_editor',
      'title'    => esc_html__( 'CSS Code', 'coffeebean' ),
      'subtitle' => esc_html__( 'Paste your CSS code here.', 'coffeebean' ),
      'mode'     => 'css',
      'theme'    => 'monokai'
    )
  )
) );

Redux::setSection( $opt_name, array(
  'title'            => esc_html__( 'Header & Menu', 'coffeebean' ),
  'id'               => 'header',
  'desc'             => esc_html__( 'Website Header options', 'coffeebean' ),
  'customizer_width' => '400px',
  'icon'             => 'el el-screen',
) );

Redux::setSection( $opt_name, array(
  'title'            => esc_html__( 'Logo', 'coffeebean' ),
  'id'               => 'logo-header',
  'subsection'       => true,
  'customizer_width' => '450px',
  'desc'             => esc_html__( 'Setting for Header Logo', 'coffeebean' ),
  'fields'           => array(
    array(
      'id'       => 'logo_upload',
      'type'     => 'media',
      'url'      => true,
      'title'    => esc_html__( 'Header Logo', 'coffeebean' ),
      'compiler' => 'true',
      'subtitle' => esc_html__( 'Upload any media using the WordPress native uploader', 'coffeebean' ),
    ),
    array(
      'id'       => 'alt_logo_upload',
      'type'     => 'media',
      'url'      => true,
      'title'    => esc_html__( 'Header alternative logo', 'coffeebean' ),
      'compiler' => 'true',
      'subtitle' => esc_html__( 'Upload any media using the WordPress native uploader', 'coffeebean' ),
    ),
    array(
      'id'       => 'logo_text',
      'type'     => 'text',
      'title'    => esc_html__( 'Logo text', 'coffeebean' ),
      'subtitle'     => esc_html__( 'Type here if you want Logo as Text', 'coffeebean' )
    ),
    /*array(
      'id'       => 'logo_maincolor',
      'type'     => 'color',
      'output'   => array('color' => 'h1.logo a, #logo h1'),
      'title'    => esc_html__( 'Logo text Color', 'coffeebean' ),
      'subtitle' => esc_html__( 'Pick a text color for Logo', 'coffeebean' ),
      'transparent'         => false
    ),*/
    array(
      'id'             => 'logo_width',
      'type'           => 'dimensions',
      'units'          => array( 'px' ),
      'title'          => esc_html__( 'Logo width', 'coffeebean' ),
      'subtitle'       => esc_html__( 'Set specify width for Logo Image in pixels', 'coffeebean' ),
      /*'height'         => false*/
    )
  )
) );

Redux::setSection( $opt_name, array(
  'title'            => esc_html__( 'Favicon', 'coffeebean' ),
  'id'               => 'favicon-header',
  'subsection'       => true,
  'customizer_width' => '450px',
  'desc'             => esc_html__( 'Setting for Favicon', 'coffeebean' ),
  'fields'           => array(
    array(
      'id'       => 'favicon_upload',
      'type'     => 'media',
      'url'      => true,
      'title'    => esc_html__( 'Favicon image', 'coffeebean' ),
      'compiler' => 'true',
      'mode'      => false, // Can be set to false to allow any media type, or can also be set to any mime type.
      'subtitle'     => esc_html__( 'Upload favicon here - PNG or ICO 16x16px', 'coffeebean' )
    )
  )
) );

Redux::setSection( $opt_name, array(
  'title'            => esc_html__( 'Header Menu', 'coffeebean' ),
  'id'               => 'menu-header',
  'subsection'       => true,
  'customizer_width' => '450px',
  'desc'             => esc_html__( 'Setting for Header Menu', 'coffeebean' ),
  'fields'           => array(
    array(
      'id'            => 'submenu_width',
      'type'          => 'slider',
      'title'         => esc_html__( 'Submenu width in Header menu', 'coffeebean' ),
      'subtitle'      => esc_html__( 'Set width for Submenu', 'coffeebean' ),
      'default'       => 190,
      'min'           => 100,
      'step'          => 1,
      'max'           => 400,
      'display_value' => 'text'
    ),
    array(
      'id'       => 'super_header',
      'type'     => 'switch',
      'title'    => esc_html__( 'Super Header', 'coffeebean' ),
      'subtitle' => esc_html__( 'Turn off to hide Super Header overlay', 'coffeebean' ),
      'default'  => true
    ),
    array(
      'id'       => 'header_fullwidth',
      'type'     => 'switch',
      'title'    => esc_html__( 'Full Width top bar', 'coffeebean' ),
      'subtitle' => esc_html__( 'Turn it on if you want Full width for top bar with Logo and Menu', 'coffeebean' ),
      'default'  => false
    ),
    array(
      'id'       => 'accordeon_dropdown',
      'type'     => 'switch',
      'title'    => esc_html__( 'Accordeon dropdown menu', 'coffeebean' ),
      'subtitle' => esc_html__( 'Turn on accordeon dropdown menu for mobile version', 'coffeebean' ),
      'default'  => false
    )
  )
) );

Redux::setSection( $opt_name, array(
  'title'            => esc_html__( 'Blog', 'coffeebean' ),
  'id'               => 'blog',
  'desc'             => esc_html__( 'Blog options', 'coffeebean' ),
  'customizer_width' => '400px',
  'icon'             => 'el el-comment',
  'fields'           => array(
    array(
      'id'       => 'blog_main_page',
      'type'     => 'select',
      'data'     => 'pages',
      'title'    => esc_html__( 'Blog main page', 'coffeebean' ),
      'subtitle' => esc_html__( 'Choose main Blog page for linking Posts navigation', 'coffeebean' ),
    ),
    array(
      'id'       => 'blog_title',
      'type'     => 'text',
      'title'    => esc_html__( 'Blog page title', 'coffeebean' ),
      'subtitle'     => esc_html__( 'Type here if you want change default blog tittle', 'coffeebean' )
    ),
    array(
      'id'       => 'blog_title_show',
      'type'     => 'switch',
      'title'    => esc_html__( 'Show Blog Title', 'coffeebean' ),
      'subtitle' => esc_html__( 'Turn it off to hide title', 'coffeebean' ),
      'default'  => true
    ),
    array(
      'id'       => 'hide_related',
      'type'     => 'switch',
      'title'    => esc_html__( 'Show Related Posts', 'coffeebean' ),
      'subtitle' => esc_html__( 'Show related posts in Post Page', 'coffeebean' ),
      'default'  => true
    ),
    array(
      'id'       => 'hide_comments',
      'type'     => 'switch',
      'title'    => esc_html__( 'Hide comments', 'coffeebean' ),
      'subtitle' => esc_html__( 'Force hide comments for all pages', 'coffeebean' ),
      'default'  => false
    ),
    array(
      'id'       => 'blog_words_count',
      'type'     => 'select',
      'title'    => esc_html__( 'Words count', 'coffeebean' ),
      'subtitle' => esc_html__( 'How many words of post to show on Blog page', 'coffeebean' ),
      'options'  => array(
        '15' => '15',
        '20' => '20',
        '30' => '30',
        '40' => '40',
        '50' => '50',
      ),
      'default'  => '30'
    ),
          /*array(
              'id'       => 'blog_layout',
              'type'     => 'button_set',
              'title'    => esc_html__( 'Blog layout', 'coffeebean' ),
              'subtitle' => esc_html__( 'Choose sidebar side on blog', 'coffeebean' ),
              'options' => array(
                  '1' => esc_html__( 'Left Sidebar', 'coffeebean' ),
                  '2' => esc_html__( 'No Sidebar', 'coffeebean' ),
                  '3' => esc_html__( 'Right Sidebar', 'coffeebean' )
              ),
              'default'  => '2'
          ),*/
  )
) );

Redux::setSection( $opt_name, array(
  'title'            => esc_html__( 'Portfolio', 'coffeebean' ),
  'id'               => 'portfolio',
  'desc'             => esc_html__( 'Portfolio options', 'coffeebean' ),
  'customizer_width' => '400px',
  'icon'             => 'el el-picture',
  'fields'           => array(
    array(
      'id'       => 'portfolio_main_page',
      'type'     => 'select',
      'data'     => 'pages',
      'title'    => esc_html__( 'Portfolio main page', 'coffeebean' ),
      'subtitle' => esc_html__( 'Choose main Portfolio page for linking Portfolio navigation', 'coffeebean' ),
    ),
    array(
      'id'       => 'portfolio_showpost',
      'type'     => 'select',
      'title'    => esc_html__( 'Item numbers', 'coffeebean' ),
      'subtitle' => esc_html__( 'Portfolio number of items to display', 'coffeebean' ),
      'options'  => array(
        '3' => '3',
        '4' => '4',
        '5' => '5',
        '6' => '6',
        '7' => '7',
        '8' => '8',
        '9' => '9',
        '10' => '10',
        '11' => '11',
        '12' => '12',
        '13' => '13',
        '14' => '14',
        '15' => '15',
        '16' => '16',
        '32' => '32',
        '64' => '64',
        '99' => '99',
      ),
      'default'  => '12'
    ),
    array(
      'id'       => 'portfolio_default_style',
      'type'     => 'select',
      'title'    => esc_html__( 'Default style for Recent Projects', 'coffeebean' ),
      'subtitle' => esc_html__( 'Choose between Classic and Masonry style', 'coffeebean' ),
      'options'  => array(
        'classic-style' => esc_html__( 'Classic', 'coffeebean' ),
        'masonry-style' => esc_html__( 'Masonry', 'coffeebean' ),
      ),
      'default'  => 'classic-style'
    ),
    array(
      'id'       => 'recent_filters_off',
      'type'     => 'switch',
      'title'    => esc_html__( 'Show fiters for Recent projects', 'coffeebean' ),
      'subtitle' => esc_html__( 'Turn off to hide them', 'coffeebean' ),
      'default'  => false
    ),
    array(
      'id'       => 'infinite_off',
      'type'     => 'switch',
      'title'    => esc_html__( 'Infinite scroll', 'coffeebean' ),
      'subtitle' => esc_html__( 'Turn off to enable loading by click', 'coffeebean' ),
      'default'  => true
    ),
    array(
      'id'       => 'recent_portfolio',
      'type'     => 'switch',
      'title'    => esc_html__( 'Recent Projects', 'coffeebean' ),
      'subtitle' => esc_html__( 'Turn off to to hide recent projects', 'coffeebean' ),
      'default'  => true
    ),
    array(
      'id'       => 'recent_showpost',
      'type'     => 'select',
      'title'    => esc_html__( 'Recent Projects items', 'coffeebean' ),
      'subtitle' => esc_html__( 'How many Recent Projects number of items to display', 'coffeebean' ),
      'options'  => array(
        '3' => '3',
        '4' => '4',
        '8' => '8',
        '12' => '12',
        '16' => '16',
        '24' => '24',
        '32' => '32',
        '48' => '48',
      ),
      'default'  => '32'
    ),
  )
) );

Redux::setSection( $opt_name, array(
  'title'            => esc_html__( 'Contact page Map', 'coffeebean' ),
  'id'               => 'map',
  'desc'             => esc_html__( 'Map settings for Contacts Page', 'coffeebean' ),
  'customizer_width' => '400px',
  'icon'             => 'el el-map-marker',
  'fields'           => array(
    array(
      'id'       => 'map_key',
      'type'     => 'text',
      'title'    => esc_html__( 'Google Map API Key', 'coffeebean' ),
      'desc'     => esc_html__( 'Please follow this link to get a Google API key - https://developers.google.com/maps/documentation/javascript/get-api-key', 'coffeebean' ),
      'subtitle'     => esc_html__( 'It may be necessary to register a Google API key in order to allow the Google Maps to load correctly.', 'coffeebean' )
    ),
    // array(
    //   'id'       => 'map_address',
    //   'type'     => 'textarea',
    //   'title'    => esc_html__( 'Address', 'coffeebean' ),
    //   'subtitle'     => esc_html__( 'Type full address here', 'coffeebean' )
    // ),
    array(
      'id'       => 'map_lat',
      'type'     => 'text',
      'title'    => esc_html__( 'Latitude', 'coffeebean' ),
      'subtitle'     => esc_html__( 'Example: 51.151786', 'coffeebean' )
    ),
    array(
      'id'       => 'map_lon',
      'type'     => 'text',
      'title'    => esc_html__( 'Longitude', 'coffeebean' ),
      'subtitle'     => esc_html__( 'Example: 10.415039', 'coffeebean' )
    ),
    array(
      'id'       => 'map_height',
      'type'     => 'select',
      'title'    => esc_html__( 'Map height', 'coffeebean' ),
      'subtitle' => esc_html__( 'Choose height for map in percents', 'coffeebean' ),
      'default'  => '50',
      'options'  => array(
        '100' => '100',
        '50' => '50',
        '30' => '30',
      )
    ),
    array(
      'id'       => 'map_off',
      'type'     => 'switch',
      'title'    => esc_html__( 'Show map', 'coffeebean' ),
      'subtitle' => esc_html__( 'Turn off to hide map in Contacts page', 'coffeebean' ),
      'default'  => true
    )
  )
) );

Redux::setSection( $opt_name, array(
  'title'            => esc_html__( 'Typography & Color', 'coffeebean' ),
  'id'               => 'typography-set',
  'desc'             => esc_html__( 'Typography options', 'coffeebean' ),
  'customizer_width' => '400px',
  'icon'             => 'el el-font'
) );

Redux::setSection( $opt_name, array(
  'title'            => esc_html__( 'Typography', 'coffeebean' ),
  'id'               => 'fonts-set',
  'subsection'       => true,
  'desc'             => esc_html__( 'Typography options. It may be necessary to register a Google Fonts API key in order to allow the Google Fonts to load correctly. Please follow this link to get a Google Fonts API key - https://developers.google.com/fonts/docs/developer_api. Then paste your key into Settings > Google API key.', 'coffeebean' ),
  'customizer_width' => '400px',
  'fields'           => array(
    array(
      'id'       => 'logo_font',
      'type'     => 'typography',
      /*'output'   => array('h2.logo a, h1.logo a, h1.logo, #logo h1'),*/
      'title'    => esc_html__( 'Logo font', 'coffeebean' ),
      'subtitle' => esc_html__( 'Specify the Logo font properties.', 'coffeebean' ),
      'google'   => true,
      'text-align'   => false
    ),
    array(
      'id'       => 'menu_font',
      'type'     => 'typography',
      /*'output'   => array('#navigation a, .widget_nav_menu a'),*/
      'title'    => esc_html__( 'Menu font', 'coffeebean' ),
      'subtitle' => esc_html__( 'Specify the Menu font properties.', 'coffeebean' ),
      'google'   => true,
      'text-align'   => false
    ),
    array(
      'id'       => 'body_font',
      'type'     => 'typography',
      /*'output'   => array('body, .date, .post-meta, .readmore, .widget, .comment-text, .search-results, .post-content p, .container p'),*/
      'title'    => esc_html__( 'Body font', 'coffeebean' ),
      'subtitle' => esc_html__( 'Specify the Body font properties.', 'coffeebean' ),
      'google'   => true,
      'text-align'   => false,
    ),
    array(
      'id'       => 'h1_font',
      'type'     => 'typography',
      /*'output'   => array('h1:not(.logo)'),*/
      'title'    => esc_html__( 'H1 font', 'coffeebean' ),
      'subtitle' => esc_html__( 'Header H1 font properties.', 'coffeebean' ),
      'google'   => true,
      'text-align'   => false
    ),
    array(
      'id'       => 'h2_font',
      'type'     => 'typography',
      /*'output'   => array('h2'),*/
      'title'    => esc_html__( 'H2 font', 'coffeebean' ),
      'subtitle' => esc_html__( 'Header H2 font properties.', 'coffeebean' ),
      'google'   => true,
      'text-align'   => false,
    ),
    array(
      'id'       => 'h3_font',
      'type'     => 'typography',
      /*'output'   => array('h3'),*/
      'title'    => esc_html__( 'H3 font', 'coffeebean' ),
      'subtitle' => esc_html__( 'Header H3 font properties.', 'coffeebean' ),
      'google'   => true,
      'text-align'   => false,
    ),
    array(
      'id'       => 'h4_font',
      'type'     => 'typography',
      /*'output'   => array('h4'),*/
      'title'    => esc_html__( 'H4 font', 'coffeebean' ),
      'subtitle' => esc_html__( 'Header H4 font properties.', 'coffeebean' ),
      'google'   => true,
      'text-align'   => false,
    ),
    array(
      'id'       => 'h5_font',
      'type'     => 'typography',
      /*'output'   => array('h5'),*/
      'title'    => esc_html__( 'H5 font', 'coffeebean' ),
      'subtitle' => esc_html__( 'Header H5 font properties.', 'coffeebean' ),
      'google'   => true,
      'text-align'   => false,
    ),
    array(
      'id'       => 'h6_font',
      'type'     => 'typography',
      /*'output'   => array('h6'),*/
      'title'    => esc_html__( 'H6 font', 'coffeebean' ),
      'subtitle' => esc_html__( 'Header H6 font properties.', 'coffeebean' ),
      'google'   => true,
      'text-align'   => false,
    ),
  )
) );

Redux::setSection( $opt_name, array(
  'title'            => esc_html__( 'Links & Main Color', 'coffeebean' ),
  'id'               => 'color-set',
  'subsection'       => true,
  'desc'             => esc_html__( 'Links color options', 'coffeebean' ),
  'customizer_width' => '400px',
  'fields'           => array(
    array(
      'id'       => 'links_color',
      'type'     => 'color',
      'title'    => esc_html__( 'Main Color and Links Color', 'coffeebean' ),
      'subtitle' => esc_html__( 'Pick a links and main color for theme', 'coffeebean' ),
      'transparent'         => false
    )
  )
) );

Redux::setSection( $opt_name, array(
  'title'            => esc_html__( 'Global Colors', 'coffeebean' ),
  'id'               => 'global-colors',
  'subsection'       => true,
  'desc'             => esc_html__( 'Website color options', 'coffeebean' ),
  'customizer_width' => '400px',
  'fields'           => array(
    array(
      'id'       => 'menu_color',
      'type'     => 'color',
      'title'    => esc_html__( 'Menu Links Color', 'coffeebean' ),
      'subtitle' => esc_html__( 'Choose color for main menu', 'coffeebean' ),
      'transparent'         => false
    ),
    array(
      'id'       => 'menu_background_color',
      'type'     => 'color',
      'title'    => esc_html__( 'Menu Background Color', 'coffeebean' ),
      'subtitle' => esc_html__( 'Choose color for main menu background', 'coffeebean' ),
      'transparent'         => false
    ),
    array(
      'id'       => 'title_color',
      'type'     => 'color',
      'title'    => esc_html__( 'Titles Font Color', 'coffeebean' ),
      'subtitle' => esc_html__( 'Choose color for in Portfolio, Blog and Pages titles and headers', 'coffeebean' ),
      'transparent'         => false
    ),
    array(
      'id'       => 'title_background_color',
      'type'     => 'color',
      'title'    => esc_html__( 'Title Background Color (Portfolio and Blog)', 'coffeebean' ),
      'subtitle' => esc_html__( 'Choose color for title background in Portfolio and Blog', 'coffeebean' ),
      'transparent'         => false
    ),
    array(
      'id'       => 'page_font_color',
      'type'     => 'color',
      'title'    => esc_html__( 'Page Font Color', 'coffeebean' ),
      'subtitle' => esc_html__( 'Choose color for content in page', 'coffeebean' ),
      'transparent'         => false
    ),
    array(
      'id'       => 'page_background_color',
      'type'     => 'color',
      'title'    => esc_html__( 'Page Background Color', 'coffeebean' ),
      'subtitle' => esc_html__( 'Choose page backgournd color', 'coffeebean' ),
      'transparent'         => false
    )
  )
) );

// If Redux is running as a plugin, this will remove the demo notice and links
add_action( 'redux/loaded', 'remove_demo' );

if ( ! function_exists( 'redux_validate_callback_function' ) ) {
  function redux_validate_callback_function( $field, $value, $existing_value ) {
    $error   = false;
    $warning = false;

    //do your validation
    if ( $value == 1 ) {
      $error = true;
      $value = $existing_value;
    } elseif ( $value == 2 ) {
      $warning = true;
      $value   = $existing_value;
    }

    $return['value'] = $value;

    if ( $error == true ) {
      $return['error'] = $field;
      $field['msg']    = 'your custom error message';
    }

    if ( $warning == true ) {
      $return['warning'] = $field;
      $field['msg']      = 'your custom warning message';
    }

    return $return;
  }
}

/**
 * Custom function for the callback referenced above
 */
if ( ! function_exists( 'redux_my_custom_field' ) ) {
  function redux_my_custom_field( $field, $value ) {
    print_r( $field );
    echo '<br/>';
    print_r( $value );
  }
}

/**
 * Custom function for filtering the sections array. Good for child themes to override or add to the sections.
 * Simply include this function in the child themes functions.php file.
 * NOTE: the defined constants for URLs, and directories will NOT be available at this point in a child theme,
 * so you must use get_template_directory_uri() if you want to use any of the built in icons
 * */
if ( ! function_exists( 'dynamic_section' ) ) {
  function dynamic_section( $sections ) {
    //$sections = array();
    $sections[] = array(
      'title'  => __( 'Section via hook', 'coffeebean' ),
      'desc'   => __( '<p class="description">This is a section created by adding a filter to the sections array. Can be used by child themes to add/remove sections from the options.</p>', 'coffeebean' ),
      'icon'   => 'el el-paper-clip',
      // Leave this as a blank section, no options just some intro text set above.
      'fields' => array()
    );
    return $sections;
  }
}

/**
 * Filter hook for filtering the args. Good for child themes to override or add to the args array. Can also be used in other functions.
 * */
if ( ! function_exists( 'change_arguments' ) ) {
  function change_arguments( $args ) {
  //$args['dev_mode'] = true;
  return $args;
  }
}

/**
 * Filter hook for filtering the default value of any given field. Very useful in development mode.
 * */
if ( ! function_exists( 'change_defaults' ) ) {
  function change_defaults( $defaults ) {
    $defaults['str_replace'] = 'Testing filter hook!';
    return $defaults;
  }
}

/**
 * Removes the demo link and the notice of integrated demo from the redux-framework plugin
 */
if ( ! function_exists( 'remove_demo' ) ) {
  function remove_demo() {
    // Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
    if ( class_exists( 'ReduxFrameworkPlugin' ) ) {
      remove_filter( 'plugin_row_meta', array(
        ReduxFrameworkPlugin::instance(),
        'plugin_metalinks'
      ), null, 2 );

      // Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
      remove_action( 'admin_notices', array( ReduxFrameworkPlugin::instance(), 'admin_notices' ) );
    }
  }
}
