<?php

add_filter( 'widget_text', 'do_shortcode' );
add_filter( 'ot_show_pages', '__return_false' );
add_filter( 'ot_theme_mode', '__return_true' );
add_filter( 'ot_show_new_layout', '__return_false' );
add_filter( 'ot_use_theme_options', '__return_false' );
add_filter( 'ot_meta_boxes', '__return_true' );

include get_template_directory() . '/admin/option-tree/ot-loader.php';
include get_template_directory() . '/admin/meta-boxes.php';
include get_template_directory() . '/admin/options.php';
include get_template_directory() . '/admin/widgets.php';
include get_template_directory() . '/admin/customcss.php';
include get_template_directory() . '/admin/builder_output.php';
include get_template_directory() . '/admin/builder_settings.php';
require_once( ABSPATH . 'wp-admin/includes/media.php' );

/* ----------------------------------------------------- */
/* Redux */
/* ----------------------------------------------------- */

if ( !isset( $redux_opt ) && file_exists( get_template_directory() . '/admin/config.php' ) ) {
  require_once( get_template_directory() . '/admin/config.php' );
}

/* ----------------------------------------------------- */
/* Theme Install */
/* ----------------------------------------------------- */

add_action('after_setup_theme', 'coffeebean_newtheme_install');

if (!function_exists('coffeebean_newtheme_install')):
  function coffeebean_newtheme_install() {
    add_theme_support('automatic-feed-links');
    add_theme_support( 'custom-header' );
    add_theme_support( 'custom-background' );
		add_theme_support( 'title-tag' );
    add_theme_support( 'align-wide' );
		add_theme_support('post-formats', array('gallery', 'video', 'quote', 'link'));
		add_editor_style( 'css/editor-style.min.css' );
		register_nav_menu( 'menu-header', 'Header menu' );
		load_theme_textdomain( 'coffeebean', get_template_directory() . '/languages' );
	}
endif;

if (!function_exists('redux_opt')):
  function redux_opt( $option, $suboption = null ) {
    global $redux_opt;
    if ( isset($redux_opt[$option][$suboption]) ) {
      return $result = ($suboption) ? $redux_opt[$option][$suboption] : $redux_opt[$option];
    } else { return false; }
  }
endif;

if ( ! isset( $content_width ) ) {
	$content_width = 1200;
}

/* ----------------------------------------------------- */
/* Scripts */
/* ----------------------------------------------------- */

function coffeebean_scripts() {
	wp_enqueue_script( 'carousel', get_template_directory_uri() . '/js/owl.carousel.min.js', array( 'jquery' ), false, true );
	wp_enqueue_script( 'justifiedGallery', get_template_directory_uri() . '/js/jquery.justifiedGallery.min.js', array( 'jquery' ), false, true );
	wp_enqueue_script( 'gallery', get_template_directory_uri() . '/js/gallery.js', array( 'jquery' ), false, true );
	wp_enqueue_script( 'coffeebean-masonry', get_theme_file_uri( '/js/masonry.min.js' ), array( 'jquery' ), false, true );
	wp_enqueue_script( 'imagesloaded' );
	wp_enqueue_script( 'classie', get_template_directory_uri() . '/js/classie.min.js', array( 'jquery' ), false, true );
  wp_enqueue_script( 'fancybox', get_template_directory_uri() . '/js/fancybox.js', array( 'jquery' ), false, true );
  // wp_enqueue_script( 'magnific-popup', get_template_directory_uri() . '/js/jquery.magnific-popup.min.js', array( 'jquery' ), false, true );
  wp_enqueue_script( 'fitvids', get_template_directory_uri() . '/js/fitvids.js', array( 'jquery' ), false, true );

  if (!redux_opt( 'infinite_off' ) || '0' != redux_opt( 'infinite_off' )) {
    wp_enqueue_script( 'appear', get_template_directory_uri() . '/js/jquery.appear.js', array( 'jquery' ), false, true );
  }

  if (!redux_opt('preloader_on') || '0' != redux_opt('preloader_on') ) {
		wp_enqueue_script( 'lazyload', get_template_directory_uri() . '/js/lazyload.min.js', array( 'jquery' ), false, true );
	}

	if ( is_singular() && comments_open() ) {
		wp_enqueue_script('comment-reply');
	}

  wp_enqueue_script( 'custom', get_template_directory_uri() . '/js/custom.min.js', array( 'jquery' ), false, true );
  wp_localize_script( 'custom', 'infinite_url', array( 'ajax_url' => admin_url( 'admin-ajax.php' ) ) );

  wp_enqueue_script( 'selectFx', get_template_directory_uri() . '/js/selectFx.js', array( 'jquery' ), false, true );
  wp_add_inline_script( 'selectFx', "(function() { [].slice.call( document.querySelectorAll( 'select.cs-select' ) ).forEach( function(el) { new SelectFx(el); } ); })();");

  if (get_post_meta(get_the_ID(), 'coffeebean_gallery_layout', TRUE) == "masonry-gallery" ) {
    wp_add_inline_script( 'jquery-migrate', "( function( $ ) { $(document).ready(function() { getMasonryHeight(); });    $(window).resize(function() { getMasonryHeight(); }); function getMasonryHeight() { $('.portfolio-gallery-item').each( function() { var ratio = $( this ).attr( 'data-ratio' ); var img_width = $( this ).width(); if ( ratio > 1 ) { var div_height = img_width / ratio; } else { var div_height = img_width / ratio; }     $( this ).css( { 'height': Math.floor( div_height ) } ); }); } } )( jQuery );");
  }

	wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/font/css/font-awesome.min.css', array(), '4.3' );
	wp_enqueue_style( 'justifiedGallery', get_template_directory_uri() . '/css/justifiedGallery.min.css', array(), '4.3' );
	wp_enqueue_style( 'base', get_template_directory_uri() . '/css/base.min.css', array(), '4.3' );
	wp_enqueue_style( 'fancybox', get_template_directory_uri() . '/css/fancybox.min.css' );
  // wp_enqueue_style( 'magnific-popup', get_template_directory_uri() . '/css/magnific-popup.min.css' );
  wp_enqueue_style( 'word-animation', get_template_directory_uri() . '/css/word-animation.min.css' );
  wp_enqueue_style( 'responsive', get_template_directory_uri() . '/css/responsive.min.css', array(), '4.3' );
	wp_enqueue_style( 'style', get_stylesheet_uri() );
}

add_action( 'wp_enqueue_scripts', 'coffeebean_scripts' );

/* ----------------------------------------------------- */
/* Google fonts */
/* ----------------------------------------------------- */

function coffeebean_fonts_url() {
  $font_url = '';

  /* Translators: If there are characters in your language that are not supported
  by chosen font(s), translate this to 'off'. Do not translate into your own language. */

  if ( 'off' !== _x( 'on', 'Google font: on or off', 'coffeebean' ) ) {
    $font_url = add_query_arg( 'family', urlencode( 'Josefin Sans:300,regular,600,700|Lato:300,regular|Inconsolata:regular,700|Dosis:regular' ), "//fonts.googleapis.com/css" );
  }
  return $font_url;
}

function coffeebean_fonts_init() {
  wp_enqueue_style( 'Google-font', coffeebean_fonts_url(), array(), '1.0.0' );
}

add_action( 'wp_enqueue_scripts', 'coffeebean_fonts_init' );

/* ----------------------------------------------------- */
/* Thumbs */
/* ----------------------------------------------------- */

add_theme_support('post-thumbnails');
set_post_thumbnail_size(600, 300, true);
add_image_size('coffeebean_portfolio-main', 800, 800, true);
add_image_size('coffeebean_portfolio-masonry', 800, 0, true);
add_image_size('coffeebean_portfolio-footer', 150, 150, true);

/* ----------------------------------------------------- */
/* Sidebars */
/* ----------------------------------------------------- */

function coffeebean_sidebars() {
	register_sidebar( array(
		'name' 			=> esc_html__('Default sidebar', 'coffeebean'),
		'id' 			=> 'coffeebean_sidebar1',
    'description'   => esc_html__('Sidebar used for all pages by default', 'coffeebean'),
		'before_widget'	=> '<aside id="%1$s" class="widget %2$s">',
		'after_widget'	=> '</aside>',
		'before_title'	=> '<h6 class="widget-title"><span>',
		'after_title'	=> '</span></h6>',
	) );

	register_sidebar( array(
		'name' 			=> esc_html__('Contact Page sidebar', 'coffeebean'),
		'id' 			=> 'coffeebean_sidebar2',
    'description'   => esc_html__('Sidebar only for Contact Page template', 'coffeebean'),
		'before_widget'	=> '<aside id="%1$s" class="widget %2$s">',
		'after_widget'	=> '</aside>',
		'before_title'	=> '<h6 class="widget-title"><span>',
		'after_title'	=> '</span></h6>',
	) );

	register_sidebar( array(
		'name' 			=> esc_html__('Super-Header 1', 'coffeebean'),
		'id' 			=> 'coffeebean_header_sidebar1',
    'description'   => esc_html__('Super-Header sidebar for 1st position', 'coffeebean'),
		'before_widget'	=> '<aside id="%1$s" class="widget %2$s">',
		'after_widget'	=> '</aside>',
		'before_title'	=> '<h6 class="widget-title"><span>',
		'after_title'	=> '</span></h6>',
	) );

	register_sidebar( array(
		'name' 			=> esc_html__('Super-Header 2', 'coffeebean'),
		'id' 			=> 'coffeebean_header_sidebar2',
    'description'   => esc_html__('Super-Header sidebar for 2nd position', 'coffeebean'),
		'before_widget'	=> '<aside id="%1$s" class="widget %2$s">',
		'after_widget'	=> '</aside>',
		'before_title'	=> '<h6 class="widget-title"><span>',
		'after_title'	=> '</span></h6>',
	) );

  register_sidebar( array(
    'name' 			=> esc_html__('Super-Header 3', 'coffeebean'),
    'id' 			=> 'coffeebean_header_sidebar3',
    'description'   => esc_html__('Super-Header sidebar for 3rd position', 'coffeebean'),
    'before_widget'	=> '<aside id="%1$s" class="widget %2$s">',
    'after_widget'	=> '</aside>',
    'before_title'	=> '<h6 class="widget-title"><span>',
    'after_title'	=> '</span></h6>',
  ) );

  register_sidebar( array(
    'name' 			=> esc_html__('Super-Header 4', 'coffeebean'),
    'id' 			=> 'coffeebean_header_sidebar4',
    'description'   => esc_html__('Super-Header sidebar for 4th position', 'coffeebean'),
    'before_widget'	=> '<aside id="%1$s" class="widget %2$s">',
    'after_widget'	=> '</aside>',
    'before_title'	=> '<h6 class="widget-title"><span>',
    'after_title'	=> '</span></h6>',
  ) );

	register_sidebar( array(
		'name' 			=> esc_html__('Footer 1', 'coffeebean'),
		'id' 			=> 'coffeebean_footer_overlay1',
    'description'   => esc_html__('Sidebar in Footer for left position', 'coffeebean'),
		'before_widget'	=> '<aside id="%1$s" class="widget %2$s">',
		'after_widget'	=> '</aside>',
		'before_title'	=> '<h6 class="widget-title"><span>',
		'after_title'	=> '</span></h6>',
	) );

	register_sidebar( array(
		'name' 			=> esc_html__('Footer 2', 'coffeebean'),
		'id' 			=> 'coffeebean_footer_overlay2',
    'description'   => esc_html__('Sidebar in Footer for center position', 'coffeebean'),
		'before_widget'	=> '<aside id="%1$s" class="widget %2$s">',
		'after_widget'	=> '</aside>',
		'before_title'	=> '<h6 class="widget-title"><span>',
		'after_title'	=> '</span></h6>',
	) );

	register_sidebar( array(
		'name' 			=> esc_html__('Footer 3', 'coffeebean'),
		'id' 			=> 'coffeebean_footer_overlay3',
    'description'   => esc_html__('Sidebar in Footer for right position', 'coffeebean'),
		'before_widget'	=> '<aside id="%1$s" class="widget %2$s">',
		'after_widget'	=> '</aside>',
		'before_title'	=> '<h6 class="widget-title"><span>',
		'after_title'	=> '</span></h6>',
	) );

	register_sidebar( array(
		'name' 			=> esc_html__('Footer copyright', 'coffeebean'),
		'id' 			=> 'coffeebean_footer_copyright',
    'description'   => esc_html__('Sidebar in Footer with copyright in center', 'coffeebean'),
		'before_widget'	=> '<aside id="%1$s" class="widget %2$s">',
		'after_widget'	=> '</aside>',
		'before_title'	=> '<h6 class="widget-title"><span>',
		'after_title'	=> '</span></h6>',
	) );
};

add_action( 'widgets_init', 'coffeebean_sidebars' );

/* ----------------------------------------------------- */
/* Nav menu */
/* ----------------------------------------------------- */

class coffeebean_SplitMenuWalker extends Walker_Nav_Menu {

  private $split_at;
  private $button;
  private $count = 0;
  private $wrappedOutput;
  private $replaceTarget;
  private $wrapped = false;
  private $toSplit = false;

  public function __construct($split_at = 5, $button = '<a href="#" class="menu-overflowed">&hellip;</a>') {
    $this->split_at = $split_at;
    $this->button = $button;
  }

  public function walk($elements, $max_depth, ...$args) {
    $args = array_slice(func_get_args(), 2);
    $output = parent::walk($elements, $max_depth, reset($args));
    return $this->toSplit ? $output.'</ul></li>' : $output;
  }

  public function start_el(&$output, $item, $depth = 0, $args = array(), $id = 0 ) {
    $this->count += $depth === 0 ? 1 : 0;
    parent::start_el($output, $item, $depth, $args, $id);
    if (($this->count === $this->split_at) && ! $this->wrapped) {
      // split at number has been reached generate and store wrapped output
      $this->wrapped = true;
      $this->replaceTarget = $output;
      $this->wrappedOutput = $this->wrappedOutput($output);
    } elseif(($this->count === $this->split_at + 1) && ! $this->toSplit) {
      // split at number has been exceeded, replace regular with wrapped output
      $this->toSplit = true;
      $output = str_replace($this->replaceTarget, $this->wrappedOutput, $output);
    }
  }

  public function start_lvl(&$output, $depth = 0, $args = array()) {
    $indent = str_repeat("\t", $depth);
    $output .= "$indent<ul class=\"sub-menu\"><span class=\"sub-menu-holder\">\n";
  }

  public function end_lvl(&$output, $depth = 0, $args = array()) {
    $output .= "</span></ul>\n";
  }

  private function wrappedOutput($output) {
    $dom = new DOMDocument;
    $dom->loadHTML($output.'</li>');
    $lis = $dom->getElementsByTagName('li');
    $last = trim(substr($dom->saveHTML($lis->item($lis->length-1)), 0, -5));
    // remove last li
    $wrappedOutput = substr(trim($output), 0, -1 * strlen($last));
    $classes = array(
     'menu-item',
     'menu-item-type-custom',
     'menu-item-object-custom',
     'menu-item-has-children',
     'menu-item-split-wrapper'
    );
    // add wrap li element
    $wrappedOutput .= '<li class="'.implode(' ', $classes).'">';
    // add the "more" link
    $wrappedOutput .= $this->button;
    // add the last item wrapped in a submenu and return
    return $wrappedOutput . '<ul class="sub-menu">'. $last;
  }
}

/* ----------------------------------------------------- */
/* Getting global options */
/* ----------------------------------------------------- */

class coffeebean_GetGlobal {
  function __construct() {
    global $columns, $homepage, $item_width, $related, $nopadding, $masonry, $masonry_style;
    $this->columns = $columns;
    $this->homepage = $homepage;
    $this->item_width = $item_width;
    $this->related = $related;
    $this->nopadding = $nopadding;
    $this->masonry = $masonry;
    $this->masonry_style = $masonry_style;
  }
}

/* ----------------------------------------------------- */
/* Portfolio Style */
/* ----------------------------------------------------- */

function coffeebean_portfolio_style_output() {
  $portfolio_style = 'no-effects'; $hide_h1 = '';
  $coffeebean_portfolio_style = get_post_meta(get_the_ID(), 'coffeebean_portfolio_style', true);
  $coffeebean_gallery_layout = get_post_meta(get_the_ID(), 'coffeebean_gallery_layout', true);
  $coffeebean_blog_style = get_post_meta(get_the_ID(), 'coffeebean_blog_style', true);

  if (!is_archive() && !is_search()) {
  	if ($coffeebean_portfolio_style) {
  		if ( $coffeebean_gallery_layout == "slider-gallery" ) {
  			$portfolio_style = $coffeebean_portfolio_style;
  		} else {
  			$portfolio_style = $coffeebean_portfolio_style;
  			$portfolio_style = (get_post_meta(get_the_ID(), 'coffeebean_portfolio_type', true) == "gallery") ? str_replace("intro-effect-fadeout", "no-effects height-minimal", $portfolio_style) : $portfolio_style;
  			if ( $coffeebean_gallery_layout == "tiled-gallery" || "masonry-gallery" ) {
  				$portfolio_style .= " height-minimal";
  			}
  		}
  	}

  	if ( $coffeebean_blog_style ) {
  		if ( $coffeebean_gallery_layout == "slider-gallery") {
  			$portfolio_style = $coffeebean_blog_style;
  		} else {
  			$portfolio_style = $coffeebean_blog_style;
  			$portfolio_style = (get_post_format() == "gallery") ? str_replace("intro-effect-fadeout", "no-effects height-minimal", $portfolio_style) : $portfolio_style;

  				$portfolio_style .= " height-minimal";

  		}
  	}
  }

  if ( is_home()) {
  	$portfolio_style = 'no-effects';
  }

  if (is_page_template( 'template-portfoliofull-video.php' ) || is_page_template( 'template-portfolio3col-header.php' ) || is_page_template( 'template-portfolio4col-header.php' ) || is_page_template( 'template-portfolio3-masonry-header.php' ) || is_page_template( 'template-portfolio4-masonry-header.php')) {
  	$portfolio_style = 'intro-effect-fadeout';
  }

  if ( is_page_template( 'template-portfolio3col.php' ) || is_page_template( 'template-portfolio4col.php' ) || is_page_template( 'template-portfoliofull.php' ) ) {
  	$portfolio_style = '';
  }

  if (has_post_thumbnail()) {
  	$thumbnail_full = wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), 'full' );
  	$thumbnail_url = $thumbnail_full[0];
  }

  if ( !isset($thumbnail_url) || !has_post_thumbnail() && get_post_format(get_the_ID()) == '' ) {
  	if (!is_archive() && !is_search() && is_singular()) {
  		$portfolio_style = (get_post_format() == "gallery") ? $coffeebean_blog_style . ' height-minimal' : 'no-effects no-featured height-half';
  	}
  }

  if (get_post_meta(get_the_ID(), 'coffeebean_hide_h1', true) == 'off' && get_post_meta(get_the_ID(), 'coffeebean_h1_position', true) != 'under') {
  	$hide_h1 = ' hide-h1';
  }

  return $portfolio_style . $hide_h1;
}

/* ----------------------------------------------------- */
/* Fancybox & Video output Function */
/* ----------------------------------------------------- */

function coffeebean_add_fancybox() {
/*print <<<END
  <script type="text/javascript">
  	( function( $ ) {
  		$(document).ready(function() {
  			$('a#group').fancybox({
    			beforeShow : function() {
    	      if ($(this.element).attr('alt')) {
    	        this.title = $(this.element).attr('alt');
    	      }
    	      if ($(this.element).find('img').attr('alt')) {
    	        this.title = $(this.element).find('img').attr('alt');
    	      }
            if ($(this.element).attr('data-caption')) {
    	        this.title = $(this.element).attr('data-caption');
    	      }
    	    },
    			'transitionIn'	:	'elastic',
    			'transitionOut'	:	'elastic',
    			'speedIn'		:	600,
    			'speedOut'		:	200,
    			'overlayShow'	:	false,
    			helpers:  {
    				title:  { type : 'inside' }
    			}
    		});
    		$( '.hentry' ).fitVids();
  		});
  	} )( jQuery );
  </script>
END; */
}

/* ----------------------------------------------------- */
/* Alternative Logo */
/* ----------------------------------------------------- */

function coffeebean_enable_alt_output() {
  $enable_alt_logo = get_post_meta(get_the_ID(), 'coffeebean_enable_alt', true);
  $logo_options = '';

  if ( redux_opt('alt_logo_upload', 'url') ) {
    $logo_options .= 'data-alt="' . esc_url( redux_opt('alt_logo_upload', 'url') ) . '" data-original="' . esc_url( redux_opt('logo_upload', 'url') ) . '"' ;
  }

  if ( get_post_meta(get_the_ID(), 'coffeebean_enable_alt', true) || get_post_meta(get_the_ID(), 'coffeebean_enable_alt_pf', true) ) {
    $logo_options .= 'class="';
    if (get_post_meta(get_the_ID(), 'coffeebean_enable_alt', true)) {
      $enable_alt = get_post_meta(get_the_ID(), 'coffeebean_enable_alt', TRUE);
    } else {
      $enable_alt = get_post_meta(get_the_ID(), 'coffeebean_enable_alt_pf', TRUE);
    }
    if (isset($enable_alt[0])) {
      $logo_options .= "enable_alt";
    }
    $logo_options .= '"';
  }

  return $logo_options;
}

/* ----------------------------------------------------- */
/* Getting Video */
/* ----------------------------------------------------- */

function coffeebean_get_video($video_url) {
  //global $wp_embed;
  //return $wp_embed->run_shortcode('[embed  width="600" height="360"]' . esc_url( $video_url ) . '[/embed]');

  $video_hosting = (strrpos($video_url, 'youtube')) ? 'https://www.youtube.com/embed/' : 'https://player.vimeo.com/video';
  $video_autoplay = (get_post_meta(get_the_ID(), 'coffeebean_video_autoplay', TRUE) == 'on') ? '?autoplay=1' : '';
  $embed_video_url = (strrpos($video_url, 'youtube')) ? mb_substr( $video_url, strrpos($video_url, '=') + 1) : mb_substr( $video_url, strrpos($video_url, '/'));
  return '<iframe src="' . $video_hosting .  $embed_video_url  . $video_autoplay . '" width="600" height="360" frameborder="0" webkitallowfullscreen mozallowfullscreen allowfullscreen class="hentry"></iframe>';
}

/* ----------------------------------------------------- */
/* Output Map in Contacts Page */
/* ----------------------------------------------------- */

function coffeebean_contact_map( $param = false ) {
  $map_address = esc_attr(redux_opt('map_address'));
  $map_height = (redux_opt('map_height')) ? esc_attr(redux_opt('map_height')) : '50';

  if ( $map_address || redux_opt('map_lat') ) {
  	$mapID = rand (1, 999);
  	$prepAddr = esc_attr( str_replace(' ', '+', $map_address) );
  	$geocode = wp_remote_fopen('https://maps.googleapis.com/maps/api/geocode/json?address='. $prepAddr .'&key=AIzaSyD_we8roTtUU83gU5HDS8fndwaOTUHgJYk');
  	$output = json_decode($geocode);
  	$latitude = ( $map_address && isset($output->results[0]) ) ? esc_attr($output->results[0]->geometry->location->lat) : '';
  	$longitude = ( $map_address && isset($output->results[0]) ) ? esc_attr($output->results[0]->geometry->location->lng) : '';

    $latitude = ( redux_opt('map_lat') ) ? esc_attr(redux_opt('map_lat')) : $latitude;
  	$longitude = ( redux_opt('map_lon') ) ? esc_attr(redux_opt('map_lon')) : $longitude;

    $output = '<div id="googlemaps-ID1" class="google-map map_height' . esc_attr($map_height) . '" data-map="' . esc_attr($prepAddr) . '"></div>';

  	return $output = ($param) ? "var latitude = " . $latitude . ", longitude = " . $longitude . ";" : $output;
  }
}

function coffeebean_map_init() {
  $google_maps_api_key = ( redux_opt('map_key') ) ? esc_attr(redux_opt('map_key')) : '';
  if ( is_page_template("template-contact.php") && redux_opt('map_off') != '0' ) {
    wp_enqueue_script( 'maps', 'https://maps.googleapis.com/maps/api/js?key=' . $google_maps_api_key, 'jquery', '2.1', true );
    // wp_enqueue_script( 'maplace', get_template_directory_uri() . '/js/maplace.min.js', array( 'jquery' ), false, true );
    wp_enqueue_script( 'googlemap', get_template_directory_uri() . '/js/googlemap.js', array( 'jquery' ), false, true );
    wp_add_inline_script ( 'googlemap', coffeebean_contact_map('coordinates'), 'before');
  }
}

add_action( 'wp_enqueue_scripts', 'coffeebean_map_init' );

/* ----------------------------------------------------- */
/* Infinite AJAX loading and filtering */
/* ----------------------------------------------------- */

add_action( 'wp_ajax_nopriv_ajax_infinite', 'ajax_infinite' );
add_action( 'wp_ajax_ajax_infinite', 'ajax_infinite' );

function ajax_infinite() {
	$perpage = $_POST['perpage'];
	$filter = $_POST['filter'];
  global $columns;
  $columns = $_POST['columns'];
  // $exclude = $_POST['exclude'];
  $exclude = (isset($_POST['exclude'])) ? $_POST['exclude'] : '';

  $exclude = (isset($exclude)) ? explode(",", substr( $exclude, 0, -1 )) : '';
  $filter = ( $filter != 'all' ) ? explode(",", $filter) : $filter;
	$tax_query = ( $filter != 'all' ) ? array( array( 'taxonomy' => 'filters', 'field' => 'term_id', 'terms' => $filter, 'operator' => 'IN' ) ) : '';

	$args = array(
		'post_type' => 'portfolio',
		'posts_per_page' => $perpage,
    'post_status' => 'publish',
    'post__not_in' => $exclude,
		'tax_query' => $tax_query,
    // 'meta_query' => array( array(
		// 	'key' => '_thumbnail_id',
		// 	'compare' => 'EXISTS'
		// ))
	);

	$portfolio_query = new WP_Query( $args );

	if ( defined( 'DOING_AJAX' ) && DOING_AJAX ) {
		if ( $portfolio_query->have_posts() ) :
			while ( $portfolio_query->have_posts() ) : $portfolio_query->the_post();
        if (!post_password_required()) {
          get_template_part( 'content-loop' );
          $exclude[] = get_the_ID();
        }
			endwhile;
		endif;
	}
	die();
}

/* ----------------------------------------------------- */
/* LoadMore Function */
/* ----------------------------------------------------- */

function coffeebean_load_more( $filters_array = '', $columns = 'one-third column', $data_all = false, $posts_per_page = 6 ) {
  $posts_per_page = (!empty($posts_per_page)) ? $posts_per_page : redux_opt('portfolio_showpost');
  $show_more = ( redux_opt('infinite_off') != '0' ) ? '&nbsp;' : esc_attr__( 'Show more','coffeebean' );
  $data_loading = ( redux_opt('portfolio_loadmore_animation') != '0' ) ? '&nbsp;' : esc_attr__( 'Loading...', 'coffeebean' );
  $load_svg = get_template_directory_uri() . '/images/three-dots.svg';
  $data_all = (!empty($data_all)) ? $data_all : coffeebean_get_tax_filters( $filters_array, 'count' );

  echo '<div class="load-more">';
  if (redux_opt('portfolio_loadmore_animation') != '0') {
    echo '<img class="loadmore-img" src="'. esc_url( $load_svg ) . '" />';
  }
  echo '<a href="#" id="next-projects" data-all="'. esc_attr( $data_all ) .'" data-perpage="'. esc_attr( $posts_per_page ) .'" data-filter="'. coffeebean_get_tax_filters( $filters_array ) .'" data-load="' . esc_attr( $show_more ) . '" data-loading="' . esc_attr( $data_loading ) . '" data-columns="'. esc_attr( $columns ) .'">';
  echo esc_attr( $show_more )
    . '</a>'
    . '</div>';
}

/* ----------------------------------------------------- */
/* Infinite Scroll Function */
/* ----------------------------------------------------- */

function coffeebean_get_appear($selector = '.load-more') {
  $selector = esc_attr($selector);
print <<<END
  <script type="text/javascript">
    jQuery(document).ready(function() {
      jQuery('$selector').appear();
      jQuery(document.body).on('appear', '$selector', function() {
        if ( jQuery( '#next-projects' ).data( 'perpage' ) < jQuery( '#next-projects' ).attr( 'data-all' ) ) {
          jQuery( '#next-projects' ).click();
        }
      });
    });
  </script>
END;
}

/* ----------------------------------------------------- */
/* Get filters list */
/* ----------------------------------------------------- */

function coffeebean_get_tax_filters( $filters_array, $count = '' ) {
  $tax_filters = ''; $tax_count = 0;

  if (is_array( $filters_array )) {
  	foreach ( $filters_array as $filter ) {
  		$term = get_term( $filter, 'filters' );
  		$tax_filters .= $term->term_id .",";
  		//$tax_count = $term->count + $tax_count;
  	}
  	$tax_filters = substr( $tax_filters, 0, -1 );

    $query = new WP_Query( array(
    	'post_type' => 'portfolio',
    	'tax_query' => array(	array(
    			'taxonomy' => 'filters',
    			'field'    => 'term_id',
    			'terms'    => explode( ",", $tax_filters ),
    	))
    ));

    $tax_count = $query->found_posts;
  }

  $filters = ( $tax_filters ) ? $tax_filters : 'all';
  $data_all = ( $tax_count > 0 ) ? $tax_count : wp_count_posts( 'portfolio' )->publish;

  return $output = ( 'count' == $count ) ? $data_all : $filters;
}

/* ----------------------------------------------------- */
/* Social Share in posts/portfolio */
/* ----------------------------------------------------- */

function coffeebean_share_me() {
  if (redux_opt('enable_share') !== 0) { ?>
    <div class="post-share">
      <?php esc_html_e( 'Share:', 'coffeebean' ); ?>
      <a href="https://twitter.com/intent/tweet?text=<?php the_title(); ?>+<?php the_permalink(); ?>" class="fa fa-twitter" target="_blank"></a>
      <a href="https://www.facebook.com/share.php?u=<?php the_permalink(); ?>&title=<?php the_title(); ?>" class="fa fa-facebook" target="_blank"></a>
      <!--<a href="https://plus.google.com/share?url=<?php the_permalink(); ?>" class="fa fa-google-plus" target="_blank"></a>-->
      <?php $pinterestimage = wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), 'full' ); ?>
      <a href="https://pinterest.com/pin/create/button/?url=<?php echo urlencode( get_permalink( get_the_ID() ) ); ?>&media=<?php echo esc_url($pinterestimage[0]); ?>&description=<?php the_title(); ?>" class="fa fa-pinterest-p" target="_blank"></a>
    </div>
  <?php }
}

/* ----------------------------------------------------- */
/* Words animation */
/* ----------------------------------------------------- */

function coffeebean_get_words() {
  $words = esc_attr(get_post_meta(get_the_ID(), 'coffeebean_title_words', true));
  $words = ($words) ? explode(",", $words) : '';
  if ( is_array($words) ) { $i = 0;
    echo '<span class="cd-words-wrapper">';
    foreach ( $words as $word ) {
      $visible = ($i == 0) ? 'class=is-visible' : '';
      if ($word != ' ') {
        echo '<b '. esc_attr($visible) .'>' . esc_html($word) . '</b>';
      } $i++;
    }
    echo '</span>';
  }
}

/* ----------------------------------------------------- */
/* Portfolio Gallery Setup */
/* ----------------------------------------------------- */

add_filter( 'use_default_gallery_style', '__return_false' );
add_filter( 'the_content', 'coffeebean_im_add_rel_attribute' );
add_filter( 'wp_get_attachment_link', 'coffeebean_add_rel_attribute' );

function coffeebean_add_rel_attribute($link) {
	return str_replace('<a href', '<a data-fancybox="group" href', $link);
}

function coffeebean_im_add_rel_attribute($content) {
	$string = '/<a href="(.*?).(jpg|jpeg|png|gif|bmp|ico)"><img(.*?)class="(.*?)wp-image-(.*?)" \/><\/a>/i';
	preg_match_all( $string, $content, $matches, PREG_SET_ORDER);

	//Check which attachment is referenced
	foreach ($matches as $val) {
		$post = get_post($val[5]);
		$slimbox_caption = (isset($post->post_content)) ? esc_attr( $post->post_content ) : "";
		$string = '<a href="' . $val[1] . '.' . $val[2] . '"><img' . $val[3] . 'class="' . $val[4] . 'wp-image-' . $val[5] . '" /></a>';
		$replace = '<a data-fancybox="group" href="' . $val[1] . '.' . $val[2] . '" ><img' . $val[3] . 'class="' . $val[4] . 'wp-image-' . $val[5] . '" /></a>';
		$content = str_replace( $string, $replace, $content);
	}

	return $content;
}

add_filter('img_caption_shortcode', 'coffeebean_fix_img_caption_shortcode', 10, 3);

function coffeebean_fix_img_caption_shortcode($val, $attr, $content = null) {
  extract(shortcode_atts(array(
    'id'    => '',
    'align' => '',
    'width' => '',
    'caption' => ''
  ), $attr));

  if ( 1 > (int) $width || empty($caption) ) return $val;

  return '<div id="' . esc_attr($id) . '" class="wp-caption ' . esc_attr($align) . '" style="width: ' . (0 + (int) $width) . 'px">' . do_shortcode( $content ) . '<p class="wp-caption-text">' . $caption . '</p></div>';
}

/* ----------------------------------------------------- */
/* Comments Setup */
/* ----------------------------------------------------- */

function coffeebean_wrap_comment_text($content) {
  return "<div class=\"comment-content\"><p>". $content ."</p></div>";
}
add_filter('comment_text', 'coffeebean_wrap_comment_text');

/* ----------------------------------------------------- */
/* User Custom Fields */
/* ----------------------------------------------------- */

add_action( 'show_user_profile', 'coffeebean_add_extra_social_links' );
add_action( 'edit_user_profile', 'coffeebean_add_extra_social_links' );

function coffeebean_add_extra_social_links( $user ) { ?>
  <h3><?php esc_attr_e('User Profile Links', 'coffeebean') ?></h3>

  <table class="form-table">
    <tr>
      <th><label for="facebook_profile"><?php esc_attr_e('Facebook Profile', 'coffeebean') ?></label></th>
      <td><input type="text" name="facebook_profile" value="<?php echo esc_attr(get_the_author_meta( 'facebook_profile', $user->ID )); ?>" class="regular-text" /></td>
    </tr>
    <tr>
      <th><label for="twitter_profile"><?php esc_attr_e('Twitter Profile', 'coffeebean') ?></label></th>
      <td><input type="text" name="twitter_profile" value="<?php echo esc_attr(get_the_author_meta( 'twitter_profile', $user->ID )); ?>" class="regular-text" /></td>
    </tr>
    <tr>
      <th><label for="google_profile"><?php esc_attr_e('Google+ Profile', 'coffeebean') ?></label></th>
      <td><input type="text" name="google_profile" value="<?php echo esc_attr(get_the_author_meta( 'google_profile', $user->ID )); ?>" class="regular-text" /></td>
    </tr>
		<tr>
      <th><label for="instagram_profile"><?php esc_attr_e('Instagram Profile', 'coffeebean') ?></label></th>
      <td><input type="text" name="instagram_profile" value="<?php echo esc_attr(get_the_author_meta( 'instagram_profile', $user->ID )); ?>" class="regular-text" /></td>
    </tr>
  </table>
<?php }

add_action( 'personal_options_update', 'coffeebean_save_extra_social_links' );
add_action( 'edit_user_profile_update', 'coffeebean_save_extra_social_links' );

function coffeebean_save_extra_social_links( $user_id ) {
  update_user_meta( $user_id,'facebook_profile', sanitize_text_field( $_POST['facebook_profile'] ) );
  update_user_meta( $user_id,'twitter_profile', sanitize_text_field( $_POST['twitter_profile'] ) );
  update_user_meta( $user_id,'google_profile', sanitize_text_field( $_POST['google_profile'] ) );
	update_user_meta( $user_id,'instagram_profile', sanitize_text_field( $_POST['instagram_profile'] ) );
}

/* ----------------------------------------------------- */
/* Search Archives Display */
/* ----------------------------------------------------- */

function coffeebean_display_archives() {

  $search_posts = new WP_Query(
    array(
      'post_type' => 'post',
      'posts_per_page' => 8,
      'post_status' => 'publish',
      'nopaging' => 0,
      'post__not_in' => get_option('sticky_posts')
    )
  );

  if ($search_posts->have_posts()) :
    while ($search_posts->have_posts()) : $search_posts->the_post();

    echo '<a href="' . get_the_permalink() . '" class="dummy-media-object" >';

    if (has_post_thumbnail()) { the_post_thumbnail('portfolio-footer'); } else { echo '<div class="no-archive-thumb"></div>'; }

    echo '<h3>' . get_the_title() . '</h3></a>';

    endwhile;
  endif;

  wp_reset_query();
	wp_reset_postdata();
}

/* ----------------------------------------------------- */
/* Recents Comments */
/* ----------------------------------------------------- */

function coffeebean_recent_comments($no_comments = 6, $comment_len = 80, $avatar_size = 50) {
	$comments_query = new WP_Comment_Query();
	$comments = $comments_query->query( array( 'number' => $no_comments ) );
	$comm = '';
	if ( $comments ) : foreach ( $comments as $comment ) :
		$comm .= '<a class="dummy-media-object" href="' . esc_url( get_permalink( $comment->comment_post_ID ) ) . '#comment-' . $comment->comment_ID . '">';
		$comm .= get_avatar( $comment->comment_author_email, $avatar_size );
		$comm .= '<h3><strong>'. get_comment_author( $comment->comment_ID ) . '</strong></h3>' . '<div class="search-comment"><span>' . get_the_title($comment->comment_post_ID) . ':</span>';
		$comm .= '"' . strip_tags( substr( apply_filters( 'get_comment_text', $comment->comment_content ), 0, $comment_len ) ) . '..."</div></a>';
	endforeach; else :
		$comm .= esc_html__( 'No comments.', 'coffeebean' );
	endif;
	return $comm;
}

/* ----------------------------------------------------- */
/* Recent Portfolio */
/* ----------------------------------------------------- */

function coffeebean_recent_portfolios() {
  global $post;
  $exclude = $post->ID;
  rewind_posts();
  $filters = get_post_meta($post->ID, 'coffeebean_recent_portfolio_filters', true);
  $items = get_post_meta($post->ID, 'coffeebean_recent_portfolio_posts', true);

  $args = array(
    'post_type' => array('portfolio'),
    'post__not_in' => array($exclude),
		'posts_per_page' => '6',
    'post_status' => 'publish',
    'orderby' => 'date',
    'order' => 'DESC'
  );

  if (!empty($items)) {
    $args['post__in'] = $items;
  }

  if (!empty($filters)) {
    $newfilters = array();
    foreach ($filters as $key => $value) {
      $newfilters[] = $key;
    }

    $args['tax_query'] = array( array(
      'taxonomy' => 'filters',
      'field' => 'id',
      'terms' => $newfilters
    ) );
  }

  $wpcust = new WP_Query($args); ?>

	<div class="container portfolio_container" style="width:100%;">
	  <div id="portfolio-wrapper" class="portfolio-wrapper">

	    <?php if ( $wpcust->have_posts() ):
        while( $wpcust->have_posts() ) : $wpcust->the_post(); ?>

    			<div <?php post_class('full-item-recent portfolio-item'); ?> id="post-<?php the_ID(); ?>" >
    				<div class="picture">
    					<a href="<?php the_permalink(); ?>" class="portfolio-link"><?php the_post_thumbnail('coffeebean_portfolio-main'); ?></a>
    				</div>
    				<div class="item-description alt">
    					<a href="<?php the_permalink(); ?>" title="<?php printf( esc_html__('Link to %s', 'coffeebean'), the_title_attribute('echo=0')); ?>" rel="bookmark">
    						<h6><?php the_title(); ?></h6>
    					</a>
    				</div>
    			</div>

        <?php endwhile;
      endif; ?>
	  </div>
	  <div id="next-projects"><?php next_posts_link(''); ?></div>
	</div>

  <?php wp_reset_query();
}

/* ----------------------------------------------------- */
/* Related posts */
/* ----------------------------------------------------- */

function coffeebean_related_posts() {

  global $post;
  $tags = wp_get_post_tags( $post->ID );
  $tag_arr = ''; $i = 0;

  if ($tags) {

    foreach ( $tags as $tag ) {
      $tag_arr .= $tag->slug . ',';
    }

    $numberposts = (redux_opt('related_postcount')) ? redux_opt('related_postcount') : 3 ;

    $args = array(
		  'post_type' => 'post',
      'post_status' => 'publish',
      'tag' => $tag_arr,
      'numberposts' => $numberposts,
      'post__not_in' => array($post->ID)
    );

    $related_posts = get_posts( $args );

    if ($related_posts) {
      echo '<div class="related-posts">';
		  echo '<div id="page-title"><h3 id="related-posts">'. esc_html__('Related Posts', 'coffeebean').'</h3></div><div id="portfolio-wrapper" class="blog-grid blog-nosidebar">';

      foreach ( $related_posts as $post ) : setup_postdata( $post ); $i++;
        get_template_part('blog-loop');
      endforeach;

      echo '</div></div>';

      if ($i == 1) { ?>
        <style> .one-post { margin: 0; width: 100%; } </style>
      <?php }
    }
  }
	wp_reset_postdata();
}

/* ----------------------------------------------------- */
/* HEX to RGBA color */
/* ----------------------------------------------------- */

function coffeebean_hex2rgba($color, $opacity = false) {

  $default = 'rgb(0,0,0)';

  if (empty($color))
    return $default;

  if ($color[0] == '#' ) {
    $color = substr( $color, 1 );
  }

  if (strlen($color) == 6) {
    $hex = array( $color[0] . $color[1], $color[2] . $color[3], $color[4] . $color[5] );
  } elseif ( strlen( $color ) == 3 ) {
    $hex = array( $color[0] . $color[0], $color[1] . $color[1], $color[2] . $color[2] );
  } else {
    return $default;
  }

  $rgb =  array_map('hexdec', $hex);

  if ($opacity) {
    if (abs($opacity) > 1)
      $opacity = 1.0;
      $output = ''.implode(",",$rgb).','.$opacity.'';
  } else {
      $output = ''.implode(",",$rgb).'';
  }

  return esc_attr($output);
}

/* ----------------------------------------------------- */
/* TGM */
/* ----------------------------------------------------- */

require_once get_template_directory() . '/plugins/class-tgm-plugin-activation.php';

add_action( 'tgmpa_register', 'coffeebean_register_required_plugins' );

if (!function_exists('coffeebean_register_required_plugins')) {
function coffeebean_register_required_plugins() {

	$plugins = array(
		array(
			'name'               => esc_html__('Portfolio Installer for Coffeebean', 'coffeebean'), // The plugin name.
			'slug'               => 'portfolio-installer', // The plugin slug (typically the folder name).
			'source'             => get_template_directory() . '/plugins/portfolio-installer.zip', // The plugin source.
			'required'           => true, // If false, the plugin is only 'recommended' instead of required.
			'version'            => '2.2', // E.g. 1.0.0. If set, the active plugin must be this version or higher. If the plugin version is higher than the plugin version installed, the user will be notified to update the plugin.
			'force_activation'   => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
			'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
			'external_url'       => '', // If set, overrides default API URL and points to an external URL.
		),
    array(
			'name'               => esc_html__('Page builder by Themeworm', 'coffeebean'),
			'slug'               => 'themeworm-pagebuilder',
      'source'             => get_template_directory() . '/plugins/themeworm-pagebuilder.zip',
			'required'           => false,
			'version'            => '3.0',
			'force_activation'   => false,
			'force_deactivation' => false,
			'external_url'       => ''
		),
		array(
			'name'               => esc_html__('Contact Form 7', 'coffeebean'),
			'slug'               => 'contact-form-7',
			'required'           => false,
			'version'            => '5.0',
			'force_activation'   => false,
			'force_deactivation' => false,
			'external_url'       => ''
		),
    array(
			'name'               => esc_html__('Theme Options - Redux Framework', 'coffeebean'),
			'slug'               => 'redux-framework',
			'required'           => true,
			'version'            => '3.6',
			'force_activation'   => false,
			'force_deactivation' => false,
			'external_url'       => ''
		)
	);

  $config = array(
		'id'           => 'tgmpa',                 // Unique ID for hashing notices for multiple instances of TGMPA.
		'default_path' => '',                      // Default absolute path to pre-packaged plugins.
		'menu'         => 'tgmpa-install-plugins', // Menu slug.
		'parent_slug'  => 'themes.php',            // Parent menu slug.
		'capability'   => 'edit_theme_options',    // Capability needed to view plugin install page, should be a capability associated with the parent menu used.
		'has_notices'  => true,                    // Show admin notices or not.
		'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
		'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
		'is_automatic' => true,                   // Automatically activate plugins after installation or not.
		'message'      => '',                      // Message to output right before the plugins table.
		'strings'      => array(
			'page_title'                      => esc_html__( 'Install Required Plugins', 'coffeebean' ),
			'menu_title'                      => esc_html__( 'Install Plugins', 'coffeebean' ),
			'installing'                      => esc_html__( 'Installing Plugin: %s', 'coffeebean' ), // %s = plugin name.
			'oops'                            => esc_html__( 'Something went wrong with the plugin API.', 'coffeebean' ),
			'notice_can_install_required'     => _n_noop(
				'This theme requires the following plugin: %1$s.',
				'This theme requires the following plugins: %1$s.',
				'coffeebean'
			), // %1$s = plugin name(s).
			'notice_can_install_recommended'  => _n_noop(
				'This theme recommends the following plugin: %1$s.',
				'This theme recommends the following plugins: %1$s.',
				'coffeebean'
			), // %1$s = plugin name(s).
			'notice_cannot_install'           => _n_noop(
				'Sorry, but you do not have the correct permissions to install the %1$s plugin.',
				'Sorry, but you do not have the correct permissions to install the %1$s plugins.',
				'coffeebean'
			), // %1$s = plugin name(s).
			'notice_ask_to_update'            => _n_noop(
				'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.',
				'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.',
				'coffeebean'
			), // %1$s = plugin name(s).
			'notice_ask_to_update_maybe'      => _n_noop(
				'There is an update available for: %1$s.',
				'There are updates available for the following plugins: %1$s.',
				'coffeebean'
			), // %1$s = plugin name(s).
			'notice_cannot_update'            => _n_noop(
				'Sorry, but you do not have the correct permissions to update the %1$s plugin.',
				'Sorry, but you do not have the correct permissions to update the %1$s plugins.',
				'coffeebean'
			), // %1$s = plugin name(s).
			'notice_can_activate_required'    => _n_noop(
				'The following required plugin is currently inactive: %1$s.',
				'The following required plugins are currently inactive: %1$s.',
				'coffeebean'
			), // %1$s = plugin name(s).
			'notice_can_activate_recommended' => _n_noop(
				'The following recommended plugin is currently inactive: %1$s.',
				'The following recommended plugins are currently inactive: %1$s.',
				'coffeebean'
			), // %1$s = plugin name(s).
			'notice_cannot_activate'          => _n_noop(
				'Sorry, but you do not have the correct permissions to activate the %1$s plugin.',
				'Sorry, but you do not have the correct permissions to activate the %1$s plugins.',
				'coffeebean'
			), // %1$s = plugin name(s).
			'install_link'                    => _n_noop(
				'Begin installing plugin',
				'Begin installing plugins',
				'coffeebean'
			),
			'update_link' 					  => _n_noop(
				'Begin updating plugin',
				'Begin updating plugins',
				'coffeebean'
			),
			'activate_link'                   => _n_noop(
				'Begin activating plugin',
				'Begin activating plugins',
				'coffeebean'
			),
			'return'                          => esc_html__( 'Return to Required Plugins Installer', 'coffeebean' ),
			'plugin_activated'                => esc_html__( 'Plugin activated successfully.', 'coffeebean' ),
			'activated_successfully'          => esc_html__( 'The following plugin was activated successfully:', 'coffeebean' ),
			'plugin_already_active'           => esc_html__( 'No action taken. Plugin %1$s was already active.', 'coffeebean' ),  // %1$s = plugin name(s).
			'plugin_needs_higher_version'     => esc_html__( 'Plugin not activated. A higher version of %s is needed for this theme. Please update the plugin.', 'coffeebean' ),  // %1$s = plugin name(s).
			'complete'                        => esc_html__( 'All plugins installed and activated successfully. %1$s', 'coffeebean' ), // %s = dashboard link.
			'contact_admin'                   => esc_html__( 'Please contact the administrator of this site for help.', 'coffeebean' ),

			'nag_type'                        => 'updated', // Determines admin notice type - can only be 'updated', 'update-nag' or 'error'.
		)
	);

	tgmpa( $plugins, $config );

} } ?>

function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1717562908418';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        